@@ -4,9 +4,9 @@
 
                  Copyright (C) 2002 NetCitadel, LLC
 
-  Author:  Vadim Kurland <vadim@vk.crocodile.org>
+  Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: Address.h 206 2008-10-18 20:36:18Z vadim $
+  $Id: Address.h 236 2008-12-25 20:36:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -53,7 +53,7 @@ public:
     DECLARE_FWOBJECT_SUBTYPE(Address);
 
     Address();
-    Address(const FWObject *root,bool prepopulate);
+    Address(const FWObjectDatabase *root,bool prepopulate);
     Address(const Address&);
     virtual ~Address();
 
@@ -107,6 +107,8 @@ public:
     virtual bool cmp(const FWObject *obj) throw(FWException);
 
     bool isAny() const;
+
+    virtual bool isPrimaryObject() const { return true; }
 };
 
 }
