@@ -4,9 +4,9 @@
 
                  Copyright (C) 2006 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: AddressRange.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: AddressRange.cpp 247 2009-01-24 07:16:47Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,13 +35,26 @@ using namespace libfwbuilder;
 
 const char *AddressRange::TYPENAME={"AddressRange"};
 
-AddressRange::AddressRange() : Address(), start_address(), end_address()
+/**
+ * Empty constructor. Make sure start and end addresses are
+ * initialized to 0.
+ */
+AddressRange::AddressRange() :
+    Address(),
+    start_address(InetAddr::getAny()), end_address(InetAddr::getAny())
 {
+    Address::setNetmask(InetAddr::getAny());
 }
 
-AddressRange::AddressRange(const FWObject *root, bool prepopulate) :
-    Address(root, prepopulate), start_address(), end_address()
+/**
+ * Empty constructor. Make sure start and end addresses are
+ * initialized to 0.
+ */
+AddressRange::AddressRange(const FWObjectDatabase *root, bool prepopulate) :
+    Address(root, prepopulate),
+    start_address(InetAddr::getAny()), end_address(InetAddr::getAny())
 {
+    Address::setNetmask(InetAddr::getAny());
 }
 
 AddressRange::AddressRange(AddressRange &o) : Address() , 
