@@ -4,10 +4,10 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
            Vadim Zaliva      lord@crocodile.org
 
-  $Id: BackgroundOp.cpp 121 2008-07-02 23:00:03Z vadim $
+  $Id: BackgroundOp.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -125,7 +125,7 @@ Logger* BackgroundOp::start_operation() throw(FWException)
 
     pthread_t tid;
     pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    int err=pthread_create(&tid, &tattr, background_thread, void_pair);
+    int err = pthread_create(&tid, &tattr, background_thread, void_pair);
     switch (err)
     {
     case EAGAIN:
