@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva     lord@crocodile.org
 
-  $Id: Constants.cpp,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: Constants.cpp 35 2008-04-26 19:13:33Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -37,6 +37,11 @@ const string Constants::getLibraryDescription()
 
 const string Constants::getLibraryVersion() 
 { 
+    return string(LIBFWBUILDER_VERSION); 
+}
+
+const string Constants::getDataFormatVersion()
+{
     return string(LIBFWBUILDER_FORMAT_VERSION); 
 }
 
