@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWException.cpp 35 2008-04-26 19:13:33Z vadim $
+  $Id: FWException.cpp 234 2008-12-23 06:17:53Z vadim $
 
 
   This program is free software which we release under the GNU General Public
