@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectReference.cpp 35 2008-04-26 19:13:33Z vadim $
+  $Id: FWObjectReference.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,7 @@ FWObjectReference::FWObjectReference():FWReference()
 {
 }
 
-FWObjectReference::FWObjectReference(const FWObject *root,bool prepopulate) :
+FWObjectReference::FWObjectReference(const FWObjectDatabase *root,bool prepopulate) :
     FWReference(root,prepopulate)
 {}
 
