@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectReference.h 35 2008-04-26 19:13:33Z vadim $
+  $Id: FWObjectReference.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ class FWObjectReference : public FWReference
     DECLARE_FWOBJECT_SUBTYPE(FWObjectReference);
 
     FWObjectReference();
-    FWObjectReference(const FWObject *root,bool prepopulate);
+    FWObjectReference(const FWObjectDatabase *root,bool prepopulate);
 
     void setPointer(FWObject *o);
     void setPointer(ObjectGroup *o);
