@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWServiceReference.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: FWServiceReference.h 268 2009-04-21 03:05:51Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -35,22 +35,21 @@ namespace libfwbuilder
     class Service;
     class ServiceGroup;
 
-/**
- * This class represents object reference.
- */
-class FWServiceReference : public FWReference
-{
-    public:
+    /**
+     * This class represents object reference.
+     */
+    class FWServiceReference : public FWReference
+    {
+public:
 
-    DECLARE_FWOBJECT_SUBTYPE(FWServiceReference);
+        DECLARE_FWOBJECT_SUBTYPE(FWServiceReference);
 
-    FWServiceReference();
-    FWServiceReference(const FWObject *root);
+        FWServiceReference();
+        FWServiceReference(const FWObjectDatabase *root, bool prepopulate);
 
-    void setPointer(Service *o);
-    void setPointer(ServiceGroup *o);
-
-};
+        void setPointer(Service *o);
+        void setPointer(ServiceGroup *o);
+    };
 
 }
 
