@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Firewall.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: Firewall.cpp 245 2009-01-18 22:24:54Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -40,7 +40,6 @@
 #include <fwbuilder/IPv6.h>
 
 #include <fwbuilder/Policy.h>
-#include <fwbuilder/InterfacePolicy.h>
 #include <fwbuilder/NAT.h>
 
 #include <fwbuilder/Routing.h>
@@ -67,7 +66,7 @@ Firewall::Firewall()
    
 }
 
-Firewall::Firewall(const FWObject *root,bool prepopulate) : Host(root,prepopulate)
+Firewall::Firewall(const FWObjectDatabase *root,bool prepopulate) : Host(root,prepopulate)
 {
     setStr("platform","unknown");
     setStr("host_OS" ,"unknown");
@@ -77,15 +76,15 @@ Firewall::Firewall(const FWObject *root,bool prepopulate) : Host(root,prepopulat
 
     if (prepopulate)
     {
-        add( getRoot()->create(FirewallOptions::TYPENAME) );
+        add( getRoot()->createFirewallOptions() );
         RuleSet *p;
-        p = RuleSet::cast(getRoot()->create(Policy::TYPENAME));
+        p = getRoot()->createPolicy();
         p->setTop(true);
         add(p);
-        p = RuleSet::cast(getRoot()->create(NAT::TYPENAME));
+        p = getRoot()->createNAT();
         p->setTop(true);
         add(p);
-        p = RuleSet::cast(getRoot()->create(Routing::TYPENAME));
+        p = getRoot()->createRouting();
         p->setTop(true);
         add(p);
     }
@@ -153,6 +152,7 @@ xmlNodePtr Firewall::toXML(xmlNodePtr parent) throw(FWException)
     xmlNewProp(me, TOXMLCAST("ro"), TOXMLCAST(((getRO()) ? "True" : "False")));
 
     FWObject *o;
+
     for (FWObjectTypedChildIterator it = findByType(NAT::TYPENAME);
          it != it.end(); ++it)
     {
