@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Firewall.h 164 2008-07-27 19:15:19Z vadim $
+  $Id: Firewall.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -46,7 +46,7 @@ class Firewall : public Host
 public:
     
     Firewall();
-    Firewall(const FWObject *root,bool prepopulate);
+    Firewall(const FWObjectDatabase *root,bool prepopulate);
     virtual ~Firewall();
     
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
