@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Group.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Group.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -24,10 +24,6 @@
 
 */
 
-/*
- * $Id: Group.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
- */
-
 #ifndef __GROUP_HH_FLAG__
 #define __GROUP_HH_FLAG__
 
@@ -49,7 +45,7 @@ class Group : virtual public FWObject
     public:
 
     Group();
-    Group(const FWObject *root,bool prepopulate);
+    Group(const FWObjectDatabase *root,bool prepopulate);
     virtual ~Group();
 
     DECLARE_FWOBJECT_SUBTYPE(Group);
@@ -58,7 +54,9 @@ class Group : virtual public FWObject
     /*
      * verify whether given object type is approppriate as a child
      */
-    virtual bool    validateChild(FWObject *o);
+    virtual bool validateChild(FWObject *o);
+
+    virtual bool isPrimaryObject() const { return true; }
 
     int   getSize();
 
