@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Host.cpp 206 2008-10-18 20:36:18Z vadim $
+  $Id: Host.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,10 +45,10 @@ Host::Host()
 {
 }
 
-Host::Host(const FWObject *root,bool prepopulate) : Address(root,prepopulate)
+Host::Host(const FWObjectDatabase *root,bool prepopulate) : Address(root,prepopulate)
 {
     if (prepopulate)
-        add( getRoot()->create(HostOptions::TYPENAME) );
+        add( getRoot()->createHostOptions() );
         //add(new HostOptions() );
 }
 
@@ -121,7 +121,7 @@ Management *Host::getManagementObject()
     Management *res = dynamic_cast<Management *>(
         getFirstByType(Management::TYPENAME));
     if(!res)
-        add( res = Management::cast(getRoot()->create(Management::TYPENAME)) );
+        add( res = getRoot()->createManagement() );
 //        add(res = new Management());
     return res;
 }
