@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMP6Service.cpp 123 2008-07-05 17:38:52Z vadim $
+  $Id: ICMP6Service.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -40,7 +40,7 @@ ICMP6Service::ICMP6Service() : ICMPService()
 {
 }
 
-ICMP6Service::ICMP6Service(const FWObject *root, bool prepopulate) :
+ICMP6Service::ICMP6Service(const FWObjectDatabase *root, bool prepopulate) :
     ICMPService(root, prepopulate) 
 {
 }
