@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMPService.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: ICMPService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -42,7 +42,7 @@ ICMPService::ICMPService()
     setStr("code", "-1");
 }
 
-ICMPService::ICMPService(const FWObject *root,bool prepopulate) : Service(root,prepopulate) 
+ICMPService::ICMPService(const FWObjectDatabase *root,bool prepopulate) : Service(root,prepopulate) 
 {
     setStr("type", "-1");
     setStr("code", "-1");
