@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMPService.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: ICMPService.h 237 2008-12-28 07:12:17Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -41,15 +41,19 @@ private:
 public:
 
     ICMPService();
-    ICMPService(const FWObject *root);
+    ICMPService(const FWObjectDatabase *root,bool prepopulate);
     virtual ~ICMPService();
 
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
+    virtual xmlNodePtr toXML(xmlNodePtr xml_parent_node) throw(FWException);
 
     DECLARE_FWOBJECT_SUBTYPE(ICMPService);
 
     virtual std::string getProtocolName();
     virtual int    getProtocolNumber();
+
+    virtual bool isV4Only() { return true; }
+    virtual bool isV6Only() { return false; }
 };
 
 }
