@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPService.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: IPService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -41,7 +41,7 @@ IPService::IPService()
     setStr("protocol_num", "");
 }
 
-IPService::IPService(const FWObject *root,bool prepopulate) : Service(root,prepopulate)
+IPService::IPService(const FWObjectDatabase *root,bool prepopulate) : Service(root,prepopulate)
 {
     setStr("protocol_num", "");
 }
