@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: IPv4.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@
 #include <fwbuilder/libfwbuilder-config.h>
 
 #include <fwbuilder/IPv4.h>
-#include <fwbuilder/InterfacePolicy.h>
+#include <fwbuilder/Interface.h>
 #include <fwbuilder/XMLTools.h>
 
 using namespace std;
@@ -57,7 +57,7 @@ IPv4::IPv4() : Address()
 {
 }
 
-IPv4::IPv4(const FWObject *root, bool prepopulate) : Address(root, prepopulate)
+IPv4::IPv4(const FWObjectDatabase *root, bool prepopulate) : Address(root, prepopulate)
 {
 }
 
@@ -146,3 +146,9 @@ void IPv4::dump(std::ostream &f,bool recursive,bool brief,int offset)
     FWObject::dump(f, recursive, brief, offset);
     f << inet_addr_mask->getAddressPtr()->toString() << endl;
 }
+
+bool IPv4::isPrimaryObject() const
+{
+    return (!Interface::isA(getParent()));
+}
+
