@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4.h 206 2008-10-18 20:36:18Z vadim $
+  $Id: IPv4.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -32,6 +32,7 @@
 #include <fwbuilder/InetAddrMask.h>
 #include <fwbuilder/Address.h>
 #include <fwbuilder/FWException.h>
+#include <fwbuilder/ObjectMatcher.h>
 
 namespace libfwbuilder
 {
@@ -41,7 +42,7 @@ class IPv4 : public Address
 public:
     
     IPv4();
-    IPv4(const FWObject *root, bool prepopulate);
+    IPv4(const FWObjectDatabase *root, bool prepopulate);
 
     virtual ~IPv4();
 
@@ -66,6 +67,11 @@ public:
     virtual void setAddressNetmask(const std::string& s);
 
     virtual void dump(std::ostream &f,bool recursive,bool brief,int offset=0);
+
+    virtual bool isPrimaryObject() const;
+
+    virtual bool dispatchComplexMatch(ObjectMatcher *om, FWObject *obj)
+    { return om->checkComplexMatch(this, obj); }
 };
 
 }
