@@ -4,9 +4,9 @@
 
                  Copyright (C) 2008 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv6.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: IPv6.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -47,7 +47,7 @@
 #include <fwbuilder/Inet6AddrMask.h>
 
 #include <fwbuilder/IPv6.h>
-#include <fwbuilder/InterfacePolicy.h>
+#include <fwbuilder/Interface.h>
 #include <fwbuilder/XMLTools.h>
 
 using namespace std;
@@ -61,7 +61,7 @@ IPv6::IPv6() : Address()
     inet_addr_mask = new Inet6AddrMask();
 }
 
-IPv6::IPv6(const FWObject *root, bool prepopulate) : Address(root, prepopulate)
+IPv6::IPv6(const FWObjectDatabase *root, bool prepopulate) : Address(root, prepopulate)
 {
     delete inet_addr_mask;
     inet_addr_mask = new Inet6AddrMask();
@@ -151,3 +151,9 @@ void IPv6::dump(std::ostream &f,bool recursive,bool brief,int offset)
     FWObject::dump(f, recursive, brief, offset);
     f << inet_addr_mask->getAddressPtr()->toString() << endl;
 }
+
+bool IPv6::isPrimaryObject() const
+{
+    return (!Interface::isA(getParent()));
+}
+
