@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Interface.h 126 2008-07-07 02:32:14Z vadim $
+  $Id: Interface.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -32,6 +32,7 @@
 #include <fwbuilder/Address.h>
 #include <fwbuilder/physAddress.h>
 #include <fwbuilder/FWException.h>
+#include <fwbuilder/ObjectMatcher.h>
 
 namespace libfwbuilder
 {
@@ -66,7 +67,7 @@ private:
 public:
     
         Interface();
-        Interface(const FWObject *root,bool prepopulate);
+        Interface(const FWObjectDatabase *root,bool prepopulate);
         Interface(const Interface &i);
         virtual ~Interface();
 
@@ -168,7 +169,16 @@ public:
         
         virtual unsigned int dimension()  const { return 1; }
 
-    };
+        /**
+         * similar to hasInetAddress() but counts addresses
+         */
+        virtual int countInetAddresses(bool skip_loopback) const;
+    
+        virtual bool isPrimaryObject() const { return false; }
+
+        virtual bool dispatchComplexMatch(ObjectMatcher *om, FWObject *obj)
+        { return om->checkComplexMatch(this, obj); }
+};
 
 }
 
