@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Interval.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Interval.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -36,24 +36,35 @@ namespace libfwbuilder
 class Interval : public FWObject 
 {
 
+    std::string constructDaysOfWeek(int from_dayofweek, int to_dayofweek);
+    
 public:
 
     Interval();
-    Interval(const FWObject *root,bool prepopulate);
+    Interval(const FWObjectDatabase *root,bool prepopulate);
     
     void setStartTime(int min,int hour,int day,int month,int year,int dayofweek);
     void setEndTime(int min,int hour,int day,int month,int year,int dayofweek);
 
+    void setStartTime(int min,int hour,int day,int month,int year);
+    void setEndTime(int min,int hour,int day,int month,int year);
+    void setDaysOfWeek(const std::string &days_of_week);
+    
     void getStartTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;
     void getEndTime(int *min,int *hour,int *day,int *month,int *year,int *dayofweek) const;
 
+    std::string getDaysOfWeek();
+
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
+    virtual xmlNodePtr toXML(xmlNodePtr xml_parent_node) throw(FWException);
 
     DECLARE_FWOBJECT_SUBTYPE(Interval);
 
     virtual FWReference* createRef();
 
     bool isAny();
+
+    virtual bool isPrimaryObject() const { return true; }
 };
 
 }
