@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IntervalGroup.cpp 236 2008-12-25 20:36:41Z vadim $
+  $Id: IntervalGroup.cpp 268 2009-04-21 03:05:51Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,11 @@ IntervalGroup::~IntervalGroup() {}
 
 bool  IntervalGroup::validateChild(FWObject *o)
 { 
-    string otype=o->getTypeName();
+    FWObject *oo = o;
+    if (FWObjectReference::cast(o)!=NULL) 
+        oo = FWObjectReference::cast(o)->getPointer();
+
+    string otype = oo->getTypeName();
     return (FWObject::validateChild(o) && 
 	    (otype=="Interval" ||
 	     otype=="IntervalGroup" ||
