@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IntervalGroup.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
+  $Id: IntervalGroup.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -39,11 +39,13 @@ class IntervalGroup : public Group
     public:
 
     IntervalGroup();
-    IntervalGroup(const FWObject *root,bool prepopulate);
+    IntervalGroup(const FWObjectDatabase *root,bool prepopulate);
     virtual ~IntervalGroup();
 
     DECLARE_FWOBJECT_SUBTYPE(IntervalGroup);
 
+    virtual xmlNodePtr toXML(xmlNodePtr xml_parent_node) throw(FWException);
+
     /*
      * verify whether given object type is approppriate as a child
      */
