@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Library.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: Library.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -36,7 +36,7 @@ using namespace std;
 const char *Library::TYPENAME={"Library"};
 
 Library::Library()  {}
-Library::Library(const FWObject *root,bool prepopulate) :
+Library::Library(const FWObjectDatabase *root,bool prepopulate) :
     FWObject(root,prepopulate) {}
 
 Library::~Library() 
