@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Library.h 177 2008-08-23 23:48:45Z vadim $
+  $Id: Library.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -25,7 +25,7 @@
 */
 
 /*
- * $Id: Library.h 177 2008-08-23 23:48:45Z vadim $
+ * $Id: Library.h 236 2008-12-25 20:36:41Z vadim $
  */
 
 #ifndef __LIBRARY_HH_FLAG__
@@ -43,7 +43,7 @@ class Library : public Group
     public:
 
     Library();
-    Library(const FWObject *root,bool prepopulate);
+    Library(const FWObjectDatabase *root,bool prepopulate);
     virtual ~Library();
 
     DECLARE_FWOBJECT_SUBTYPE(Library);
@@ -55,6 +55,8 @@ class Library : public Group
      * verify whether given object type is approppriate as a child
      */
     virtual bool    validateChild(FWObject *o);
+
+    virtual bool isPrimaryObject() const { return true; }
 };
 
 }
