@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: Management.h,v 1.4 2007/08/02 05:19:28 vkurland Exp $
+  $Id: Management.h 249 2009-02-17 18:25:54Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -28,7 +28,7 @@
 #ifndef __MANAGEMENT_HH_FLAG__
 #define __MANAGEMENT_HH_FLAG__
 
-#include <fwbuilder/IPAddress.h>
+#include <fwbuilder/InetAddr.h>
 #include <fwbuilder/FWObject.h>
 
 namespace libfwbuilder
@@ -39,12 +39,13 @@ namespace libfwbuilder
         public:
 
         PolicyInstallScript();
-	PolicyInstallScript(const FWObject *root,bool prepopulate);
+	PolicyInstallScript(const FWObjectDatabase *root,bool prepopulate);
         DECLARE_FWOBJECT_SUBTYPE(PolicyInstallScript);
 
         virtual void fromXML(xmlNodePtr parent) throw(FWException);
         virtual xmlNodePtr toXML(xmlNodePtr parent) throw(FWException);
-        virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
+        virtual FWObject& shallowDuplicate(
+            const FWObject *obj, bool preserve_id = true) throw(FWException);
         virtual bool cmp(const FWObject *obj) throw(FWException);
 
         const std::string& getCommand () const;
@@ -70,12 +71,13 @@ namespace libfwbuilder
         public:
 
         SNMPManagement();
-	SNMPManagement(const FWObject *root,bool prepopulate);
+	SNMPManagement(const FWObjectDatabase *root,bool prepopulate);
         DECLARE_FWOBJECT_SUBTYPE(SNMPManagement);
 
         virtual void fromXML(xmlNodePtr parent) throw(FWException);
         virtual xmlNodePtr toXML(xmlNodePtr parent) throw(FWException);
-        virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
+        virtual FWObject& shallowDuplicate(
+            const FWObject *obj, bool preserve_id = true) throw(FWException);
         virtual bool cmp(const FWObject *obj) throw(FWException);
 
         const std::string& getReadCommunity () const;
@@ -101,10 +103,11 @@ namespace libfwbuilder
         public:
 
         FWBDManagement();
-	FWBDManagement(const FWObject *root,bool prepopulate);
+	FWBDManagement(const FWObjectDatabase *root,bool prepopulate);
         virtual ~FWBDManagement();
         DECLARE_FWOBJECT_SUBTYPE(FWBDManagement);
-        virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
+        virtual FWObject& shallowDuplicate(
+            const FWObject *obj, bool preserve_id = true) throw(FWException);
         virtual bool cmp(const FWObject *obj) throw(FWException);
 
         virtual void fromXML(xmlNodePtr parent) throw(FWException);
@@ -133,17 +136,18 @@ namespace libfwbuilder
         public:
 
         Management();
-	Management(const FWObject *root,bool prepopulate);
+	Management(const FWObjectDatabase *root,bool prepopulate);
         DECLARE_FWOBJECT_SUBTYPE(Management);
 
         virtual void fromXML(xmlNodePtr parent) throw(FWException);
         virtual xmlNodePtr toXML(xmlNodePtr parent) throw(FWException);
-        virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
+        virtual FWObject& shallowDuplicate(
+            const FWObject *obj, bool preserve_id = true) throw(FWException);
         virtual bool  cmp(const FWObject *obj) throw(FWException);
 	virtual bool  validateChild(FWObject *o);
 
-        const IPAddress& getAddress() const;
-        void             setAddress(const IPAddress&);
+        const InetAddr& getAddress() const { return addr; }
+        void setAddress(const InetAddr& a) { addr = a; }
 
         PolicyInstallScript *getPolicyInstallScript();
         SNMPManagement      *getSNMPManagement();
@@ -153,7 +157,7 @@ namespace libfwbuilder
 
         private:
 
-        IPAddress addr;
+        InetAddr addr;
     };
 }
 
