@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NAT.cpp 109 2008-06-10 23:43:36Z vadim $
+  $Id: NAT.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -42,7 +42,7 @@ NAT::NAT() : RuleSet()
     setName("NAT");
 }
 
-NAT::NAT(const FWObject *root,bool prepopulate) : RuleSet(root,prepopulate) 
+NAT::NAT(const FWObjectDatabase *root,bool prepopulate) : RuleSet(root,prepopulate) 
 {
     setName("NAT");
 }
@@ -53,7 +53,7 @@ Rule* NAT::createRule()
 {
     FWObjectDatabase* db=getRoot();
     assert(db!=NULL);
-    return Rule::cast( db->create(NATRule::TYPENAME) );
+    return db->createNATRule();
 }
 
 
