@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Network.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: Network.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ Network::Network() : Address()
     setNetmask(InetAddr(AF_INET, 32));
 }
 
-Network::Network(const FWObject *root,bool prepopulate) :
+Network::Network(const FWObjectDatabase *root,bool prepopulate) :
     Address(root, prepopulate)
 {
     setNetmask(InetAddr(AF_INET, 32));
