@@ -4,9 +4,9 @@
 
                  Copyright (C) 2008 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NetworkIPv6.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: NetworkIPv6.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -48,7 +48,7 @@ NetworkIPv6::NetworkIPv6() : Address()
     setNetmask(InetAddr(AF_INET6, 64));
 }
 
-NetworkIPv6::NetworkIPv6(const FWObject *root, bool prepopulate) :
+NetworkIPv6::NetworkIPv6(const FWObjectDatabase *root, bool prepopulate) :
     Address(root, prepopulate)
 {
     delete inet_addr_mask;
