@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectGroup.cpp 236 2008-12-25 20:36:41Z vadim $
+  $Id: ObjectGroup.cpp 272 2009-04-21 04:07:15Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -32,6 +32,7 @@
 #include <fwbuilder/ServiceGroup.h>
 #include <fwbuilder/FWServiceReference.h>
 #include <fwbuilder/FWObjectDatabase.h>
+#include <fwbuilder/Interval.h>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -46,11 +47,12 @@ ObjectGroup::~ObjectGroup() {}
 
 bool ObjectGroup::validateChild(FWObject *o)
 { 
-    string otype=o->getTypeName();
+    if (FWObjectReference::cast(o)!=NULL) return true;
 
     return (FWObject::validateChild(o) && 
             Service::cast(o)==NULL &&
             ServiceGroup::cast(o)==NULL &&
+            Interval::cast(o)==NULL &&
             FWServiceReference::cast(o)==NULL);
 }
 
