@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Policy.cpp 109 2008-06-10 23:43:36Z vadim $
+  $Id: Policy.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,18 +45,18 @@ Policy::Policy() : RuleSet()
     setName("Policy");
 }
 
-Policy::Policy(const FWObject *root,bool prepopulate) : RuleSet(root,prepopulate)
+Policy::Policy(const FWObjectDatabase *root,bool prepopulate) : RuleSet(root,prepopulate)
 {
     setName("Policy");
 }
 
 Policy::~Policy() {}
 
-Rule*   Policy::createRule()
+Rule* Policy::createRule()
 {
     FWObjectDatabase* db=getRoot();
     assert(db!=NULL);
-    return Rule::cast( db->create(PolicyRule::TYPENAME) );
+    return db->createPolicyRule();
 }
 
 
