@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Policy.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Policy.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -38,17 +38,27 @@ class Policy : public RuleSet
     public:
     
     Policy();
-    Policy(const FWObject *root,bool prepopulate);
+    Policy(const FWObjectDatabase *root,bool prepopulate);
     virtual ~Policy();
     
     DECLARE_FWOBJECT_SUBTYPE(Policy);
 
 /* the following methods provide proper typization */
-    PolicyRule* getRuleByNum(int n) { return PolicyRule::cast(RuleSet::getRuleByNum(n)); }
-    PolicyRule* insertRuleAtTop() { return PolicyRule::cast(RuleSet::insertRuleAtTop()); }
-    PolicyRule* insertRuleBefore(int n){ return PolicyRule::cast(RuleSet::insertRuleBefore(n));}
-    PolicyRule* appendRuleAfter(int n){ return PolicyRule::cast(RuleSet::appendRuleAfter(n));}
-    PolicyRule* appendRuleAtBottom(){ return PolicyRule::cast(RuleSet::appendRuleAtBottom());}
+    PolicyRule* getRuleByNum(int n) {
+        return PolicyRule::cast(RuleSet::getRuleByNum(n));
+    }
+    PolicyRule* insertRuleAtTop() {
+        return PolicyRule::cast(RuleSet::insertRuleAtTop());
+    }
+    PolicyRule* insertRuleBefore(int n){
+        return PolicyRule::cast(RuleSet::insertRuleBefore(n));
+    }
+    PolicyRule* appendRuleAfter(int n){
+        return PolicyRule::cast(RuleSet::appendRuleAfter(n));
+    }
+    PolicyRule* appendRuleAtBottom(){
+        return PolicyRule::cast(RuleSet::appendRuleAtBottom());
+    }
     
     virtual Rule*   createRule();
 
