@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Rule.cpp 352 2009-06-08 20:54:16Z vadim $
+  $Id: Rule.cpp 370 2009-06-24 16:00:58Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -278,7 +278,7 @@ string PolicyRule::getDirectionAsString() const
     case Outbound:  return "Outbound";
     case Both:      return "Both";
     }
-    return "Undefined";
+    return "Both";
 }
 
 void PolicyRule::setDirection(const string& dir)
