@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Rule.h 167 2008-08-12 16:24:41Z vadim $
+  $Id: Rule.h 252 2009-03-25 15:33:46Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -63,7 +63,7 @@ class Rule : public Group
     public:
 
     Rule();
-    Rule(const FWObject *root,bool prepopulate);
+    Rule(const FWObjectDatabase *root,bool prepopulate);
 
     DECLARE_FWOBJECT_SUBTYPE(Rule);
 
@@ -113,17 +113,11 @@ class Rule : public Group
     virtual RuleSet* getBranch();
     virtual void setBranch(RuleSet *ruleset);
 
+    virtual bool isPrimaryObject() const { return false; }
 };
 
 class PolicyRule : public Rule 
 {
-    libfwbuilder::RuleElementSrc*      src_re;
-    libfwbuilder::RuleElementDst*      dst_re;
-    libfwbuilder::RuleElementSrv*      srv_re;
-    libfwbuilder::RuleElementItf*      itf_re;
-    libfwbuilder::RuleElementInterval* when_re;
-    
-    
     public:
 /*
  * Supported policy rule actions:
@@ -182,13 +176,25 @@ class PolicyRule : public Rule
                    Outbound, 
                    Both } Direction;
 
+private:
 
+    libfwbuilder::RuleElementSrc* src_re;
+    libfwbuilder::RuleElementDst* dst_re;
+    libfwbuilder::RuleElementSrv* srv_re;
+    libfwbuilder::RuleElementItf* itf_re;
+    libfwbuilder::RuleElementInterval* when_re;
+    Action action;
+    Direction direction;
+    
+public:    
 
     PolicyRule();
-    PolicyRule(const FWObject *root,bool prepopulate);
+    PolicyRule(const FWObjectDatabase *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
-    virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
+    virtual FWObject& shallowDuplicate(const FWObject *obj,
+                                       bool preserve_id = true)
+        throw(FWException);
 
     DECLARE_FWOBJECT_SUBTYPE(PolicyRule);
     virtual FWOptions* getOptionsObject();
@@ -210,13 +216,13 @@ class PolicyRule : public Rule
     libfwbuilder::RuleElementItf*  getItf() ;
     libfwbuilder::RuleElementInterval* getWhen() ;
 
-    Action getAction() const;
-    void   setAction(Action act);
+    Action getAction() const { return action; }
+    void   setAction(Action act) { action = act; }
     std::string getActionAsString() const;
     void   setAction(const std::string& act);
 
-    Direction getDirection() const;
-    void   setDirection(Direction dir);
+    Direction getDirection() const { return direction; }
+    void   setDirection(Direction dir) { direction = dir; }
     std::string getDirectionAsString() const;
     void   setDirection(const std::string& dir);
 
@@ -241,6 +247,42 @@ class NATRule : public Rule
     
     public:
 
+/*
+ *  Supported NAT rule actions:
+ *      
+ *      Unknown - Uknown action
+ *         
+ *      NONAT - Exception to other nat rules
+ *
+ *      SNAT - Source NAT - Translate Source Address
+ *
+ *      Masq - Masquerading.
+ *
+ *      DNAT - Destnation NAT - Translate Destination Address.
+ *
+ *      SDNAT - Source & Destination NAT - Translate both source and
+ *      destination addresses.
+ *
+ *      SNetNAT - Source Network Translation - Translate source
+ *      address network.
+ *
+ *      DNetNAT - Destination Network Translation - Translate
+ *      destination address network.
+ *
+ *      Redirect - Redirect to firewall - Translate destination to a
+ *      firewall address.
+ *
+ *      Return - Internal use for rule chains.
+ *
+ *      Skip - 
+ *
+ *      Continue - Internal use for nat rules with negation.
+ *
+ *      LB - NAT Rule that does load ballencing.
+ *
+ *  NOTE: Not all types supported on all platforms.
+ *
+ */
     typedef enum { Unknown, 
                    NONAT, 
                    SNAT, 
@@ -262,7 +304,7 @@ class NATRule : public Rule
     public:
 
     NATRule();
-    NATRule(const FWObject *root,bool prepopulate);
+    NATRule(const FWObjectDatabase *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
 
@@ -306,7 +348,7 @@ class RoutingRule : public Rule
     public:
                     
     RoutingRule();
-    RoutingRule(const FWObject *root,bool prepopulate);
+    RoutingRule(const FWObjectDatabase *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
 
