@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleElement.cpp 253 2009-03-26 04:07:36Z vadim $
+  $Id: RuleElement.cpp 268 2009-04-21 03:05:51Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -202,6 +202,13 @@ xmlNodePtr RuleElementSrc::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementSrc::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 
 const char *RuleElementDst::TYPENAME={"Dst"};
@@ -229,6 +236,13 @@ xmlNodePtr RuleElementDst::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementDst::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 
 const char *RuleElementSrv::TYPENAME={"Srv"};
@@ -257,6 +271,13 @@ xmlNodePtr RuleElementSrv::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementSrv::validateChild(FWObject *o)
+{
+    if (FWServiceReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ServiceGroup::validateChild(o);
+}
+
 
 const char *RuleElementItf::TYPENAME={"Itf"};
 RuleElementItf::RuleElementItf() {}
@@ -287,20 +308,22 @@ xmlNodePtr RuleElementItf::toXML(xmlNodePtr parent) throw(FWException)
 
 bool RuleElementItf::validateChild(FWObject *o)
 {
-  if (FWObjectReference::cast(o)!=NULL) return true;  //I dont like this
-  if ( o->getId() == getAnyElementId()) return true;
-  if (Interface::cast(o)!=NULL) return checkItfChildOfThisFw(o);
-  if (ObjectGroup::cast(o)!=NULL)
-  {
-      bool all_intf = true;
-      for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
-      {
-          FWObject *o1 = FWReference::getObject(*i);
-          if (!Interface::isA(o1)) { all_intf = false; break; }
-      }
-      return all_intf;  // group is allowed if all members are interfaces
-  }
-  return false;
+    if (FWObjectReference::cast(o)!=NULL) return true;
+
+    if ( o->getId() == getAnyElementId()) return true;
+    if (Interface::cast(o)!=NULL) return checkItfChildOfThisFw(o);
+
+    if (ObjectGroup::cast(o)!=NULL)
+    {
+        bool all_intf = true;
+        for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
+        {
+            FWObject *o1 = FWReference::getObject(*i);
+            if (!Interface::isA(o1)) { all_intf = false; break; }
+        }
+        return all_intf;  // group is allowed if all members are interfaces
+    }
+    return false;
 }
 
 /*
@@ -369,6 +392,13 @@ xmlNodePtr RuleElementOSrc::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementOSrc::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 const char *RuleElementODst::TYPENAME={"ODst"};
 RuleElementODst::RuleElementODst() {}
@@ -396,6 +426,13 @@ xmlNodePtr RuleElementODst::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementODst::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 const char *RuleElementOSrv::TYPENAME={"OSrv"};
 RuleElementOSrv::RuleElementOSrv() {}
@@ -406,7 +443,8 @@ RuleElementOSrv::RuleElementOSrv(const FWObjectDatabase *root,bool prepopulate)
         _initialize(root);
 }
 
-int RuleElementOSrv::getAnyElementId() {
+int RuleElementOSrv::getAnyElementId()
+{
     return FWObjectDatabase::ANY_SERVICE_ID;
 }
 
@@ -423,6 +461,13 @@ xmlNodePtr RuleElementOSrv::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementOSrv::validateChild(FWObject *o)
+{
+    if (FWServiceReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ServiceGroup::validateChild(o);
+}
+
 
 
 
@@ -435,7 +480,8 @@ RuleElementTSrc::RuleElementTSrc(const FWObjectDatabase *root,bool prepopulate)
         _initialize(root);
 }
 
-int RuleElementTSrc::getAnyElementId() {
+int RuleElementTSrc::getAnyElementId()
+{
     return FWObjectDatabase::ANY_ADDRESS_ID;
 }
 
@@ -452,6 +498,13 @@ xmlNodePtr RuleElementTSrc::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementTSrc::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 const char *RuleElementTDst::TYPENAME={"TDst"};
 RuleElementTDst::RuleElementTDst() {}
@@ -479,6 +532,13 @@ xmlNodePtr RuleElementTDst::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementTDst::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 const char *RuleElementTSrv::TYPENAME={"TSrv"};
 RuleElementTSrv::RuleElementTSrv()  {}
@@ -508,21 +568,21 @@ xmlNodePtr RuleElementTSrv::toXML(xmlNodePtr parent) throw(FWException)
 
 bool RuleElementTSrv::validateChild(FWObject *o)
 {
-  if (FWObjectReference::cast(o)!=NULL) return true;
-  if ( o->getId() == getAnyElementId()) return true;
+    if (FWServiceReference::cast(o)!=NULL) return true;
 
-  // TagService is not allowed in translated service
-  if (TagService::isA(o)) return false;
+    if ( o->getId() == getAnyElementId()) return true;
 
-  if (ServiceGroup::cast(o)!=NULL)
-  {
-      for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
-      {
-          FWObject *o1 = FWReference::getObject(*i);
-          if (!validateChild(o1)) return false;
-      }
-  }
-  return true;
+    // TagService is not allowed in translated service
+    if (TagService::isA(o)) return false;
+    if (ServiceGroup::cast(o)!=NULL)
+    {
+        for (FWObject::iterator i=o->begin(); i!=o->end(); ++i)
+        {
+            FWObject *o1 = FWReference::getObject(*i);
+            if (!validateChild(o1)) return false;
+        }
+    }
+    return ServiceGroup::validateChild(o);
 }
 
 
@@ -554,6 +614,12 @@ xmlNodePtr RuleElementInterval::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementInterval::validateChild(FWObject *o)
+{
+    if (FWIntervalReference::cast(o)!=NULL)  return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return (Interval::cast(o)!=NULL || IntervalGroup::cast(o)!=NULL);
+}
 
 
 
@@ -582,6 +648,13 @@ xmlNodePtr RuleElementRDst::toXML(xmlNodePtr parent) throw(FWException)
     return me;
 }
 
+bool RuleElementRDst::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
+    if ( o->getId() == getAnyElementId()) return true;
+    return ObjectGroup::validateChild(o);
+}
+
 
 const char *RuleElementRGtw::TYPENAME={"RGtw"};
 RuleElementRGtw::RuleElementRGtw() {}
@@ -609,43 +682,35 @@ xmlNodePtr RuleElementRGtw::toXML(xmlNodePtr parent) throw(FWException)
 }
 
 
-bool RuleElementRGtw::validateChild(FWObject *o) {
-
+bool RuleElementRGtw::validateChild(FWObject *o)
+{
+    if (FWObjectReference::cast(o)!=NULL) return true;
     if( getChildrenCount() > 0 && !isAny()) return false;
-    
     return checkSingleIPAdress(o);
 }
 
 // check if the gateway has only one interface with only one ipv4 adress
-bool RuleElementRGtw::checkSingleIPAdress(FWObject *o) {
-
-    if( Host::cast(o) != NULL) {
-
+bool RuleElementRGtw::checkSingleIPAdress(FWObject *o)
+{
+    if( Host::cast(o) != NULL)
+    {
         list<FWObject*> obj_list = o->getByType("Interface");
-
-        if( obj_list.size() == 1) {
-
+        if( obj_list.size() == 1)
+        {
             obj_list = (obj_list.front())->getByType("IPv4");
-
-            if( obj_list.size() == 1) {
-
+            if( obj_list.size() == 1)
+            {
                 return true;
-
             } else return false;
-
         } else return false;
-
-    } else if( Interface::cast(o) != NULL) {
-
+    } else if( Interface::cast(o) != NULL)
+    {
         list<FWObject*> obj_list = o->getByType("IPv4");
-
-        if( obj_list.size() == 1) {
-
+        if( obj_list.size() == 1)
+        {
             return true;
-
         } else return false;
     }
-    
     return ( o->getId() == getAnyElementId() ||
             (FWObject::validateChild(o) && 
             (IPv4::cast(o)!=NULL || FWObjectReference::cast(o)!=NULL)));
@@ -660,11 +725,16 @@ RuleElementRItf::RuleElementRItf(const FWObjectDatabase *root,bool prepopulate)
  * Unlike RuleElementItf, RuleElementRItf can hold only single object.
  * Both RuleElementItf and RuleElementRItf can only hold Interface objects
  * which must belong to the same firewall the rule element belongs to.
- * Method RuleElementItf::validateChild checks for these conditions.
  */
 bool RuleElementRItf::validateChild(FWObject *o)
 {
-  if( getChildrenCount() > 0 && !isAny()) return false;
-  return RuleElementItf::validateChild(o);
+    if (FWObjectReference::cast(o)!=NULL) return true;
+
+    if (getChildrenCount() > 0 && !isAny()) return false;
+
+    if ( o->getId() == getAnyElementId()) return true;
+    if (Interface::cast(o)!=NULL) return checkItfChildOfThisFw(o);
+
+    return false;
 }
 
