@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva <lord@crocodile.org>
 
-  $Id: Service.cpp 105 2008-06-09 01:52:12Z vadim $
+  $Id: Service.cpp 236 2008-12-25 20:36:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,7 +35,7 @@ using namespace std;
 
 const char *Service::TYPENAME={"Service"};
 
-Service::Service(const FWObject *root,bool prepopulate) : FWObject(root,prepopulate) {}
+Service::Service(const FWObjectDatabase *root,bool prepopulate) : FWObject(root,prepopulate) {}
 
 string Service::getProtocolName()
 {
@@ -50,7 +50,7 @@ int    Service::getProtocolNumber()
 FWReference* Service::createRef()
 {
 //    FWServiceReference *ref=new FWServiceReference();
-    FWServiceReference *ref=FWServiceReference::cast(getRoot()->create(FWServiceReference::TYPENAME));
+    FWServiceReference *ref = getRoot()->createFWServiceReference();
     ref->setPointer(this);
     return ref;
 }
