@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva <lord@crocodile.org>
 
-  $Id: Service.h 35 2008-04-26 19:13:33Z vadim $
+  $Id: Service.h 237 2008-12-28 07:12:17Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -49,13 +49,20 @@ class Service : public FWObject
     DECLARE_FWOBJECT_SUBTYPE(Service);
 
     Service() {}
-    Service(const FWObject *root,bool prepopulate);
+    Service(const FWObjectDatabase *root,bool prepopulate);
 
     virtual FWReference* createRef();
     virtual std::string getProtocolName();
     virtual int    getProtocolNumber();
 
     bool isAny() const;
+
+    virtual bool isPrimaryObject() const { return true; }
+
+    // All service objects except for ICMPService, ICMP6Service and
+    // CustomService can be used in both ipv4 and ipv6 contexts.
+    virtual bool isV4Only() { return false; }
+    virtual bool isV6Only() { return false; }
 };
 
 }
