@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ServiceGroup.cpp 236 2008-12-25 20:36:41Z vadim $
+  $Id: ServiceGroup.cpp 272 2009-04-21 04:07:15Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -34,6 +34,9 @@
 #include <fwbuilder/ObjectGroup.h>
 #include <fwbuilder/FWObjectReference.h>
 #include <fwbuilder/Address.h>
+#include <fwbuilder/Interval.h>
+
+#include <iostream>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -47,11 +50,12 @@ ServiceGroup::~ServiceGroup() {}
 
 bool  ServiceGroup::validateChild(FWObject *o)
 { 
-    string otype=o->getTypeName();
+    if (FWServiceReference::cast(o)!=NULL) return true;
 
     return (FWObject::validateChild(o) && 
             Address::cast(o)==NULL &&
             ObjectGroup::cast(o)==NULL &&
+            Interval::cast(o)==NULL &&
             FWObjectReference::cast(o)==NULL);
 }
 
