@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ServiceGroup.h 177 2008-08-23 23:48:45Z vadim $
+  $Id: ServiceGroup.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -38,7 +38,7 @@ class ServiceGroup : public Group
     public:
 
     ServiceGroup();
-    ServiceGroup(const FWObject *root,bool prepopulate);
+    ServiceGroup(const FWObjectDatabase *root,bool prepopulate);
     virtual ~ServiceGroup();
 
     DECLARE_FWOBJECT_SUBTYPE(ServiceGroup);
