@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TCPService.cpp 105 2008-06-09 01:52:12Z vadim $
+  $Id: TCPService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -46,7 +46,7 @@ TCPService::TCPService()
     clearAllTCPFlagMasks();
 }
 
-TCPService::TCPService(const FWObject *root, bool prepopulate) :
+TCPService::TCPService(const FWObjectDatabase *root, bool prepopulate) :
     TCPUDPService(root,prepopulate) 
 {
     init();
