@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TCPUDPService.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: TCPUDPService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,7 @@ TCPUDPService::TCPUDPService()
     dst_range_end = 0;
 }
 
-TCPUDPService::TCPUDPService(const FWObject *root, bool prepopulate) :
+TCPUDPService::TCPUDPService(const FWObjectDatabase *root, bool prepopulate) :
     Service(root,prepopulate) 
 {
     src_range_start = 0;
