@@ -7,7 +7,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: TagService.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: TagService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ TagService::TagService()
     setStr("tagcode", "");
 }
 
-TagService::TagService(const FWObject *root,bool prepopulate) : Service(root,prepopulate)
+TagService::TagService(const FWObjectDatabase *root,bool prepopulate) : Service(root,prepopulate)
 {
     setStr("tagcode", "");
 }
