@@ -4,9 +4,9 @@
 
                  Copyright (C) 2008 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: UserService.cpp 202 2008-10-12 04:02:18Z vadim $
+  $Id: UserService.cpp 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -38,7 +38,7 @@ using namespace libfwbuilder;
 const char *UserService::TYPENAME={"UserService"};
 
 UserService::UserService() {}
-UserService::UserService(const FWObject *root, bool prepopulate) :
+UserService::UserService(const FWObjectDatabase *root, bool prepopulate) :
     Service(root, prepopulate) {}
 UserService::~UserService() {}
 
