@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Compiler.cpp 237 2008-12-28 07:12:17Z vadim $
+  $Id: Compiler.cpp 353 2009-06-08 21:33:04Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,9 @@
 #include "Compiler.h"
 
 #include "fwbuilder/libfwbuilder-config.h"
+
+#include "fwbuilder/FWServiceReference.h"
+#include "fwbuilder/FWObjectReference.h"
 #include "fwbuilder/AddressRange.h"
 #include "fwbuilder/RuleElement.h"
 #include "fwbuilder/Firewall.h"
@@ -823,7 +826,7 @@ void  Compiler::recursiveGroupsInRE::isRecursiveGroup(int grid, FWObject *obj)
         FWObject *o = FWReference::getObject(*i);
         if (Group::cast(o)!=NULL)
         {
-            if (o->getId()==grid)
+            if (o->getId()==grid || obj->getId()==o->getId())
             {
                 compiler->abort("Group '"+o->getName()+"' references itself recursively");
             }
@@ -1164,7 +1167,7 @@ Interval* Compiler::getFirstWhen(PolicyRule *rule)
 Interface* Compiler::getFirstItf(PolicyRule *rule)
 {
     RuleElementItf *itf = rule->getItf();
-    if (itf==NULL) return NULL;  // itf is optional element
+    if (itf==NULL || itf->size()==0) return NULL;  // itf is optional element
     FWObject *o = FWReference::getObject(itf->front());
     return Interface::cast(o);
 }
