@@ -4,9 +4,9 @@
 
                  Copyright (C) 2002 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NATCompiler.h 123 2008-07-05 17:38:52Z vadim $
+  $Id: NATCompiler.h 234 2008-12-23 06:17:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
