@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PolicyCompiler.cpp 352 2009-06-08 20:54:16Z vadim $
+  $Id: PolicyCompiler.cpp 429 2009-09-18 18:02:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -312,9 +312,19 @@ bool PolicyCompiler::cmpRules(PolicyRule &r1, PolicyRule &r2)
 bool PolicyCompiler::ItfNegation::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-//    FWOptions  *ruleopt =rule->getOptionsObject();
 
-    list<FWObject*> allInterfaces=compiler->fw->getByType(Interface::TYPENAME);
+    // Use getByTypeDeep() to pick subinterfaces (vlans and such)
+    list<FWObject*> all_interfaces = compiler->fw->getByTypeDeep(Interface::TYPENAME);
+    list<FWObject*> work_interfaces;
+
+    // skip unprotected interfaces bug #2710034 "PF Compiler in 3.0.3
+    // Unprotected Interface Bug"
+    for (FWObject::iterator i=all_interfaces.begin(); i!=all_interfaces.end(); ++i)
+    {
+        Interface *intf = Interface::cast(*i);
+        if (intf && intf->isUnprotected()) continue;
+        work_interfaces.push_back(intf);
+    }
 
     RuleElementItf *itfre = rule->getItf();
     if (itfre==NULL)
@@ -330,11 +340,11 @@ bool PolicyCompiler::ItfNegation::processNext()
         for (FWObject::iterator i=itfre->begin(); i!=itfre->end(); ++i)
         {
             FWObject *o = FWReference::getObject(*i);
-            allInterfaces.remove(o);
+            work_interfaces.remove(o);
         }
         itfre->reset();
         itfre->setNeg(false);
-        for (FWObject::iterator i=allInterfaces.begin(); i!=allInterfaces.end(); ++i)
+        for (FWObject::iterator i=work_interfaces.begin(); i!=work_interfaces.end(); ++i)
             itfre->addRef(*i);
     }
 
@@ -366,7 +376,11 @@ bool  PolicyCompiler::InterfacePolicyRules::processNext()
                 FWObject *o1 = FWReference::getObject(*i);
                 if (!Interface::isA(o1))
                 {
-                    compiler->warning("Object '" + o1->getName() + "', which is not an interface, is a member of the group '" + o->getName() + "' used in 'Interface' element of a rule.   Rule: " + rule->getLabel());
+                    compiler->warning(
+                        "Object '" + o1->getName() +
+                        "', which is not an interface, is a member of the group '" +
+                        o->getName() +
+                        "' used in 'Interface' element of a rule.");
                     continue;
                 }
                 PolicyRule *r= compiler->dbcopy->createPolicyRule();
@@ -688,13 +702,18 @@ Address* PolicyCompiler::checkForZeroAddr::findZeroAddress(RuleElement *re)
                  Interface::cast(o)->isBridgePort()))
                 continue;
 
-            if ( ! addr->isAny() 
-                 && addr->getAddressPtr()->isAny()
-                 && addr->getNetmaskPtr()->isAny()
-            ) 
+            if ( ! addr->isAny())
             {
-                a = addr;
-                break;
+                const InetAddr *ad = addr->getAddressPtr();
+                const InetAddr *nm = addr->getNetmaskPtr();
+                // AddressRange has address but not netmask
+                // AddressRange with address 0.0.0.0 is acceptable
+                // (not equivalent to "any")
+                if (ad->isAny() && nm!=NULL && nm->isAny())
+                {
+                    a = addr;
+                    break;
+                }
             }
         }
     }
