@@ -4,9 +4,9 @@
 
                  Copyright (C) 2006 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Preprocessor.h 171 2008-08-16 03:15:46Z vadim $
+  $Id: Preprocessor.h 234 2008-12-23 06:17:53Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
